from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from spotii_notification_client.notification.email_api import EmailApi
from spotii_notification_client.notification.sms_api import SmsApi

from spotii_notification_client.notification.sms_message import SMSMessage
from spotii_notification_client.notification.email_message import EmailMessage


# coding: utf-8

"""
    Spotii Notification API

    API for send sms/email messages  # noqa: E501

    OpenAPI spec version: v1.0
    Contact: hello@spotii.me
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import spotii_notification_client
from notification.sms_api import SmsApi  # noqa: E501
from spotii_notification_client.rest import ApiException


class TestSmsApi(unittest.TestCase):
    """SmsApi unit test stubs"""

    def setUp(self):
        self.api = notification.sms_api.SmsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_sms_messages_create(self):
        """Test case for sms_messages_create

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa

"""
    Spotii Notification API

    API for send SMS/Email messages  # noqa: E501

    OpenAPI spec version: v1.0
    Contact: hello@nuclearo.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

# import apis into sdk package
from spotii_notification_client.notification.email_api import EmailApi
from spotii_notification_client.notification.sms_api import SmsApi
# import ApiClient
from spotii_notification_client.api_client import ApiClient
from spotii_notification_client.configuration import Configuration
# import models into sdk package
from spotii_notification_client.notification.email_message import EmailMessage
from spotii_notification_client.notification.sms_message import SMSMessage



# coding: utf-8

"""
    Spotii Notification API

    API for send sms/email messages  # noqa: E501

    OpenAPI spec version: v1.0
    Contact: hello@spotii.me
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import spotii_notification_client
from notification.message import Message  # noqa: E501
from spotii_notification_client.rest import ApiException


class TestMessage(unittest.TestCase):
    """Message unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testMessage(self):
        """Test Message"""
        # FIXME: construct object with mandatory attributes with example values
        # model = spotii_notification_client.models.message.Message()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Spotii Notification API

    API for notification things  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from os import path

from setuptools import find_packages, setup  # noqa: H301

NAME = "spotii-notification-client"
VERSION = "1.0.5"
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = ["urllib3 >= 1.15", "six >= 1.10", "certifi", "python-dateutil"]

this_directory = path.abspath(path.dirname(__file__))
with open(path.join(this_directory, 'README.md'), encoding='utf-8') as f:
    long_description = f.read()

setup(
    name=NAME,
    version=VERSION,
    description="Spotii Notification API",
    author_email="hello@nuclearo.com",
    url="https://www.spotii.me/",
    keywords=["Swagger", "Spotii Notification API"],
    install_requires=REQUIRES,
    packages=find_packages(),
    include_package_data=True,
    long_description=long_description,
    long_description_content_type='text/markdown'
)
